@@ -13,9 +13,7 @@
  * Library General Public License for more details.
  *
  * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -305,21 +303,18 @@ static void
 set_label_size_request (ButtonData *button_data)
 {
         gint width, height;
-	GtkRequisition min_req, bold_req;
+	GtkRequisition nat_req, bold_req;
 
 	if (button_data->label == NULL) {
 		return;
 	}
 
-	gtk_label_set_ellipsize (GTK_LABEL (button_data->label), PANGO_ELLIPSIZE_NONE);
-	gtk_widget_get_preferred_size (button_data->label, &min_req, NULL);
-	gtk_label_set_ellipsize (GTK_LABEL (button_data->label), PANGO_ELLIPSIZE_MIDDLE);	
-
+	gtk_widget_get_preferred_size (button_data->label, NULL, &nat_req);
 	gtk_widget_get_preferred_size (button_data->bold_label, &bold_req, NULL);
 
-	width = MAX (min_req.width, bold_req.width);
+	width = MAX (nat_req.width, bold_req.width);
 	width = MIN (width, NAUTILUS_PATH_BAR_BUTTON_MAX_WIDTH);
-	height = MAX (min_req.height, bold_req.height);
+	height = MAX (nat_req.height, bold_req.height);
 
 	gtk_widget_set_size_request (button_data->label, width, height);
 }
@@ -361,7 +356,7 @@ nautilus_path_bar_get_preferred_width (GtkWidget *widget,
 		}
 
 		*minimum = MAX (*minimum, child_min);
-		*natural = MAX (*natural, child_nat);
+		*natural = *natural + child_nat;
 	}
 
 	/* Add space for slider, if we have more than one path */
@@ -741,7 +736,8 @@ nautilus_path_bar_realize (GtkWidget *widget)
 	attributes.event_mask |= 
 		GDK_SCROLL_MASK |
 		GDK_BUTTON_PRESS_MASK |
-		GDK_BUTTON_RELEASE_MASK;
+		GDK_BUTTON_RELEASE_MASK |
+		GDK_POINTER_MOTION_MASK;
 	attributes_mask = GDK_WA_X | GDK_WA_Y;
 
 	path_bar->priv->event_window = gdk_window_new (gtk_widget_get_parent_window (widget),
