@@ -16,9 +16,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  *  General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public
- *  License along with this program; if not, write to the Free
- *  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  *  Authors: Elliot Lee <sopwith@redhat.com>
  *  	     John Sullivan <sullivan@eazel.com>
@@ -73,9 +72,6 @@
 #include <math.h>
 #include <sys/time.h>
 
-/* dock items */
-#define MAX_TITLE_LENGTH 180
-
 /* Forward and back buttons on the mouse */
 static gboolean mouse_extra_buttons = TRUE;
 static int mouse_forward_button = 9;
@@ -458,6 +454,8 @@ nautilus_window_set_initial_window_geometry (NautilusWindow *window)
 	GdkScreen *screen;
 	guint max_width_for_screen, max_height_for_screen;
 	guint default_width, default_height;
+	gboolean show_sidebar;
+	GtkAction *action;
 
 	screen = gtk_window_get_screen (GTK_WINDOW (window));
 	
@@ -472,6 +470,17 @@ nautilus_window_set_initial_window_geometry (NautilusWindow *window)
 				          max_width_for_screen), 
 				     MIN (default_height, 
 				          max_height_for_screen));
+
+	show_sidebar = g_settings_get_boolean (nautilus_window_state, NAUTILUS_WINDOW_STATE_START_WITH_SIDEBAR);
+	action = gtk_action_group_get_action (window->details->main_action_group,
+					      NAUTILUS_ACTION_SHOW_HIDE_SIDEBAR);
+	gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), show_sidebar);
+
+	if (show_sidebar) {
+		nautilus_window_show_sidebar (window);
+	} else {
+		nautilus_window_hide_sidebar (window);
+	}
 }
 
 static gboolean
@@ -1019,7 +1028,9 @@ nautilus_window_sync_location_widgets (NautilusWindow *window)
 		GtkWidget *path_bar;
 
 		location_entry = nautilus_toolbar_get_location_entry (NAUTILUS_TOOLBAR (window->details->toolbar));
-		nautilus_location_entry_set_location (NAUTILUS_LOCATION_ENTRY (location_entry), location);
+		if (location_entry != NULL && GTK_IS_WIDGET (location_entry)) {
+			nautilus_location_entry_set_location (NAUTILUS_LOCATION_ENTRY (location_entry), location);
+		}
 
 		path_bar = nautilus_toolbar_get_path_bar (NAUTILUS_TOOLBAR (window->details->toolbar));
 		nautilus_path_bar_set_path (NAUTILUS_PATH_BAR (path_bar), location);
@@ -1520,12 +1531,6 @@ nautilus_window_constructed (GObject *self)
 	slot = nautilus_window_open_slot (window, 0);
 	nautilus_window_set_active_slot (window, slot);
 
-	if (g_settings_get_boolean (nautilus_window_state, NAUTILUS_WINDOW_STATE_START_WITH_SIDEBAR)) {
-		nautilus_window_show_sidebar (window);
-	} else {
-		nautilus_window_hide_sidebar (window);
-	}
-
 	window->details->bookmarks_id =
 		g_signal_connect_swapped (nautilus_application_get_bookmarks (application), "changed",
 					  G_CALLBACK (nautilus_window_sync_bookmarks), window);
@@ -1779,45 +1784,6 @@ nautilus_window_set_active_slot (NautilusWindow *window, NautilusWindowSlot *new
 	}
 }
 
-static void
-nautilus_window_get_preferred_width (GtkWidget *widget,
-				     gint *minimal_width,
-				     gint *natural_width)
-{
-	GdkScreen *screen;
-	gint max_w, min_w, default_w;
-
-	screen = gtk_window_get_screen (GTK_WINDOW (widget));	
-
-	max_w = get_max_forced_width (screen);
-	min_w = NAUTILUS_WINDOW_MIN_WIDTH;
-
-	default_w = NAUTILUS_WINDOW_DEFAULT_WIDTH;
-
-	*minimal_width = MIN (min_w, max_w);
-	*natural_width = MIN (default_w, max_w);
-}
-
-static void
-nautilus_window_get_preferred_height (GtkWidget *widget,
-				      gint *minimal_height,
-				      gint *natural_height)
-{
-	GdkScreen *screen;
-	gint max_h, min_h, default_h;
-
-	screen = gtk_window_get_screen (GTK_WINDOW (widget));	
-
-	max_h = get_max_forced_height (screen);
-
-	min_h = NAUTILUS_WINDOW_MIN_HEIGHT;
-
-	default_h = NAUTILUS_WINDOW_DEFAULT_HEIGHT;
-
-	*minimal_height = MIN (min_h, max_h);
-	*natural_height = MIN (default_h, max_h);
-}
-
 static void
 nautilus_window_realize (GtkWidget *widget)
 {
@@ -2226,8 +2192,6 @@ nautilus_window_class_init (NautilusWindowClass *class)
 
 	wclass->destroy = nautilus_window_destroy;
 	wclass->show = nautilus_window_show;
-	wclass->get_preferred_width = nautilus_window_get_preferred_width;
-	wclass->get_preferred_height = nautilus_window_get_preferred_height;
 	wclass->realize = nautilus_window_realize;
 	wclass->key_press_event = nautilus_window_key_press_event;
 	wclass->window_state_event = nautilus_window_state_event;
@@ -2368,25 +2332,9 @@ nautilus_window_show_about_dialog (NautilusWindow *window)
 		"Sun Microsystems",
 		NULL
 	};
-	const gchar *license[] = {
-		N_("Files is free software; you can redistribute it and/or modify "
-		   "it under the terms of the GNU General Public License as published by "
-		   "the Free Software Foundation; either version 2 of the License, or "
-		   "(at your option) any later version."),
-		N_("Files is distributed in the hope that it will be useful, "
-		   "but WITHOUT ANY WARRANTY; without even the implied warranty of "
-		   "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the "
-		   "GNU General Public License for more details."),
-		N_("You should have received a copy of the GNU General Public License "
-		   "along with Nautilus; if not, write to the Free Software Foundation, Inc., "
-		   "51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA")
-	};
-	gchar *license_trans, *copyright_str;
+	gchar *copyright_str;
 	GDateTime *date;
 
-	license_trans = g_strjoin ("\n\n", _(license[0]), _(license[1]),
-					     _(license[2]), NULL);
-
 	date = g_date_time_new_now_local ();
 
 	/* Translators: these two strings here indicate the copyright time span,
@@ -2400,8 +2348,7 @@ nautilus_window_show_about_dialog (NautilusWindow *window)
 			       "version", VERSION,
 			       "comments", _("Access and organize your files."),
 			       "copyright", copyright_str,
-			       "license", license_trans,
-			       "wrap-license", TRUE,
+			       "license-type", GTK_LICENSE_GPL_2_0,
 			       "authors", authors,
 			       "documenters", documenters,
 				/* Translators should localize the following string
@@ -2412,7 +2359,6 @@ nautilus_window_show_about_dialog (NautilusWindow *window)
 			      "logo-icon-name", "system-file-manager",
 			      NULL);
 
-	g_free (license_trans);
 	g_free (copyright_str);
 	g_date_time_unref (date);
 }
